==> sghi_core-0.1.2.tar.gz: lib/user_feed/src/presentation/widgets/feed_item_title_bar.dart <==
// Flutter imports:
import 'package:flutter/material.dart';
// Package imports:
import 'package:sghi_core/shared_themes/colors.dart';
import 'package:sghi_core/shared_themes/spaces.dart';
import 'package:sghi_core/shared_themes/text_themes.dart';
// Project imports:
import 'package:sghi_core/user_feed/src/application/helpers/utils.dart';

/// the top bar of the feed item
///
/// it contains the following
///
/// - an icon
/// - a tagline
/// - a timestamp
/// - an optional label
class FeedItemTitleBar extends StatelessWidget {
  const FeedItemTitleBar({
    super.key,
    required this.author,
    required this.timestamp,
    required this.iconUrl,
    required this.itemID,
  });

  final String author;
  final String iconUrl;
  final String itemID;
  final String timestamp;

  String postTimeStampAsMessage(String? timestamp) {
    if (timestamp == null) return '';
    return timestamp;
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: <Widget>[
        // icon or avatar
        Container(
          height: 45,
          width: 45,
          decoration: BoxDecoration(
            color: Colors.white,
            border: Border.all(color: Colors.black87),
            gradient: getFeedGlobalActionGradient(context),
            shape: BoxShape.circle,
            image: DecorationImage(
              fit: BoxFit.cover,
              image: NetworkImage(iconUrl),
            ),
          ),
        ),

        Flexible(
          child: Row(
            children: <Widget>[
              smallHorizontalSizedBox,
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  // the author
                  Text(author,
                      style: TextThemes.boldSize15Text(Colors.black87)),
                  extremelySmallVerticalSizedBox,

                  // the date
                  Container(
                    constraints: const BoxConstraints(maxWidth: 180),
                    child: // a formatted human readable timestamp
                        Text(
                      this.postTimeStampAsMessage(timestamp),
                      style: TextThemes.normalSize12Text(grey),
                    ),
                  ),
                ],
              )
            ],
          ),
        ),
      ],
    );
  }
}

==> sghi_core-0.3.20.tar.gz: lib/user_feed/src/presentation/widgets/feed_item_title_bar.dart <==
// Flutter imports:
import 'package:flutter/material.dart';
// Package imports:
import 'package:sghi_core/shared_themes/colors.dart';
import 'package:sghi_core/shared_themes/spaces.dart';
import 'package:sghi_core/shared_themes/text_themes.dart';
import 'package:sghi_core/ui_components/src/app_strings.dart';
// Project imports:
import 'package:sghi_core/user_feed/src/application/helpers/utils.dart';

/// the top bar of the feed item
///
/// it contains the following
///
/// - an icon
/// - a tagline
/// - a timestamp
/// - an optional label
class FeedItemTitleBar extends StatelessWidget {
  const FeedItemTitleBar({
    super.key,
    required this.author,
    required this.timestamp,
    required this.iconUrl,
    required this.itemID,
  });

  final String author;
  final String iconUrl;
  final String itemID;
  final String timestamp;

  String postTimeStampAsMessage(String? timestamp) {
    if (timestamp == null) return '';
    return timestamp;
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: <Widget>[
        // icon or avatar
        Container(
          height: 45,
          width: 45,
          decoration: BoxDecoration(
            color: Colors.white,
            border: Border.all(color: Colors.black87),
            gradient: getFeedGlobalActionGradient(context),
            shape: BoxShape.circle,
            image: const DecorationImage(
              fit: BoxFit.cover,
              image: AssetImage(bewellLogo),
            ),
          ),
        ),

        Flexible(
          child: Row(
            children: <Widget>[
              smallHorizontalSizedBox,
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  // the author
                  Text(author,
                      style: TextThemes.boldSize15Text(Colors.black87)),
                  extremelySmallVerticalSizedBox,

                  // the date
                  Container(
                    constraints: const BoxConstraints(maxWidth: 180),
                    child: // a formatted human readable timestamp
                        Text(
                      this.postTimeStampAsMessage(timestamp),
                      style: TextThemes.normalSize12Text(grey),
                    ),
                  ),
                ],
              )
            ],
          ),
        ),
      ],
    );
  }
}
